import logging

FORMAT_STR_VERBOSE_INFO = '{ %(name)s:%(lineno)d @ %(asctime)s } -'

def pit_get_logger(name: str) -> logging.Logger:
    """
    Returns a logger with some helpful presets.

    Args:
        name (str): The module name of course.

    Returns:
        logging.Logger: A python logger.
    """
    logger = logging.getLogger(name)

    handler = logging.StreamHandler()
    formatter = logging.Formatter(f'[pit] {FORMAT_STR_VERBOSE_INFO} %(message)s')
    handler.setFormatter(formatter)
    logger.addHandler(handler)

    return logger


import subprocess

def git_is_command() -> bool:
    """
    Utility for assuring that `git` is a valid command.

    Returns:
        bool: Boolean indicating if git is resolved via `which`
    """
    result = subprocess.run(
        ['git']
    )

    return result.returncode != 127 # Command not found


def git_is_inside_working_tree() -> bool:
    """
    Utility for determining if current working directory is a git repository.

    Returns:
        bool: Boolean indicating if the current working directory is a repository.
    """
    result = subprocess.run(
        ['git', 'rev-parse', '--is-inside-work-tree'],
        capture_output=True
    )

    return result.stdout.decode() == 'true\n'


from point_in_time.util import (
    git_is_command,
    git_is_inside_working_tree
)

def test_git_is_command_true():
    # Assumption: tests are run where git is command
    assert git_is_command() == True

def test_git_is_inside_repo_true(with_empy_git_repo):
    assert git_is_inside_working_tree() == True

def test_git_is_inside_repo_false(with_empty_dir):
    assert git_is_inside_working_tree() == False